#
# spec file for package motif
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           motif
Version:        2.3.8
Release:        3.4
Summary:        Motif Runtime Programs
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://motif.ics.com/
Source0:        https://sourceforge.net/projects/motif/files/Motif%%20%{version}%%20Source%%20Code/motif-%{version}.tar.gz
Source1:        mwm.desktop
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM 02-fix-format-security.patch -- http://bugs.motifzone.net/show_bug.cgi?id=1574
Patch0:         fix-format-security.patch
# PATCH-FEATURE-UPSTREAM 03-no-demos.patch -- Disable demos if not needed
Patch1:         no-demos.patch
# PATCH-FIX-UPSTREAM fix_underlinking.patch -- http://bugs.motifzone.net/show_bug.cgi?id=1583
Patch2:         fix_underlinking.patch
# PATCH-FIX-UPSTEAM 13-fix_hardcoded_x11rgb_path.patch -- http://bugs.motifzone.net/show_bug.cgi?id=1585
Patch3:         fix_hardcoded_x11rgb_path.patch
# PATCH-FIX-UPSTREM 16-fix-undefined-use-of-sprintf.patch -- http://bugs.motifzone.net/show_bug.cgi?id=1628
Patch4:         fix-undefined-use-of-sprintf.patch
Patch5:         https://git.alpinelinux.org/aports/plain/community/motif/18-option-main.patch
# PATCH-FIX-OPENSUSE fix-implicit-declarations-gcc14.patch -- Include <string.h> in order to avoid implicit declarations, fixes builds with gcc14
Patch6:         fix-implicit-declarations-gcc14.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xbitmaps)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xmu) >= 1.1.1
BuildRequires:  pkgconfig(xp)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xt)
Conflicts:      lestif2
Provides:       openmotif = %{version}
Obsoletes:      openmotif < %{version}

%description
This package provides programs of the Motif runtime enviroment.

%package -n libMrm4
Summary:        Motif Resource Manager library
Group:          System/Libraries

%description -n libMrm4
The Motif resource manager (MRM) is responsible for creating widgets
based on definitions contained in user interface definition (UID)
files created by the UIL compiler. MRM interprets the output of the
UIL compiler and generates the appropriate argument lists for widget
creation functions.

%package -n libUil4
Summary:        Motif User Interface Language library
Group:          System/Libraries

%description -n libUil4
The Motif user interface language (UIL) is a specification language
for describing the initial state of a Motif application's user
interface.

%package -n libXm4
Summary:        Motif runtime library
Group:          System/Libraries
Provides:       openmotif-libs = %{version}-%{release}
Obsoletes:      openmotif-libs < %{version}-%{release}

%description -n libXm4
This package provides the main Motif shared library.

%package devel
Summary:        Motif Include Files and Libraries Mandatory for Development
Group:          Development/Libraries/X11
Requires:       libMrm4 = %{version}
Requires:       libUil4 = %{version}
Requires:       libXm4 = %{version}
Requires:       pkgconfig(printproto)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xft)
Requires:       pkgconfig(xproto)
Requires:       pkgconfig(xt)
Conflicts:      lesstif-devel
Conflicts:      lesstifd
Conflicts:      lestif2d
Provides:       openmotif-devel = %{version}-%{release}
Obsoletes:      openmotif-devel < %{version}-%{release}

%description devel
This package provies the include files and libraries necessary for developing
Motif applications.

%prep
%autosetup -p1
sed -i 's|{libdir}/X11|{datadir}/X11|' configure.ac

%build
autoreconf -fi
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
    --disable-static \
    --disable-demos \
    --with-x11rgbdir="%{_datadir}/X11" \
    --enable-xft \
    --enable-jpeg \
    --enable-png
%make_build MWMRCDIR=%{_sysconfdir}/X11 XMBINDDIR_FALLBACK=%{_datadir}/X11/bindings

%install
%make_install MWMRCDIR=%{_sysconfdir}/X11 XMBINDDIR_FALLBACK=%{_datadir}/X11

install -D -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/xsessions/mwm.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/mwm.desktop

find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libMrm4 -p /sbin/ldconfig

%postun -n libMrm4 -p /sbin/ldconfig

%post   -n libUil4 -p /sbin/ldconfig

%postun -n libUil4 -p /sbin/ldconfig

%post   -n libXm4  -p /sbin/ldconfig

%postun -n libXm4  -p /sbin/ldconfig

%files
%dir %{_includedir}/X11/bitmaps
%{_includedir}/X11/bitmaps/xm_*
%{_datadir}/X11/bindings
%{_bindir}/mwm
%{_bindir}/xmbind
%config %{_sysconfdir}/X11/system.mwmrc
%{_mandir}/man1/mwm.1%{ext_man}
%{_mandir}/man1/xmbind.1%{ext_man}
%{_mandir}/man4/*.4%{ext_man}
%{_datadir}/xsessions/*

%files -n libMrm4
%{_libdir}/libMrm.so.4*

%files -n libUil4
%{_libdir}/libUil.so.4*

%files -n libXm4
%{_libdir}/libXm.so.4*

%files devel
%{_bindir}/uil
%{_includedir}/Mrm
%{_includedir}/uil
%{_includedir}/Xm
%{_libdir}/*.so
%{_mandir}/man1/uil.1%{ext_man}
%{_mandir}/man3/*%{ext_man}
%{_mandir}/man5/*%{ext_man}

%changelog
* Mon May 13 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Add fix-implicit-declarations-gcc14.patch
  * fixes builds with gcc14
* Fri Jun  3 2022 Jan Engelhardt <jengelh@inai.de>
- Trim old specfile constructs
- Remove --with-pic since that only affects static libs
  which are disabled.
* Sat Apr 23 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.3.8
  * Fixed bug: TextField leaves a residual cursor shadow on focus lose
  * Fixed bug: Many cases of typos in horizontal/vertical conditions in the code
  * Fixed bug: motif does crash on OpenSuse Leap 42.2
  * Fixed bug: TabStack with tabSelectColor and Right causes BadMatch Error
  * Fixed bug: Open Motif build fails due to weak aliases on Darwin with cl
  * Fixed bug: Motif 2.3.6 and 2.3.4 do not work with XQuartz 2.7.9 and later
  * Fixed bug: Add support for more Cyrillic locales
  * Fixed bug: Memory leak in DataF.c
  * Fixed bug: Closing open menus with mouse click disables keyboard shortcut
- Update to version 2.3.7
  * Fixed segmentation faults associated with option menus or other popup windows
- Update to version 2.3.6
  * Fixed Rendering issues seen while scrolling window
  * Fixed parallel building error
- Update to version 2.3.5
  * Reimplemented bugfix: The active window changes to inactive
    when the drop down list is clicked
  * Fixed XmList segfault when left-shift left-button click on
    list item
  * Fixed Label size computed wrong within a Form
  * Fixed Using deprecated X functions
  * Fixed Buffer overrun in FontS.c
  * Fixed many compile-time bugs
- Drop outdated patches:
  * openmotif-2.3.3.diff, warn.patch, strcmp.diff,
    openmotif-xpm.diff, sentinel.diff, openmotif-uil.diff,
    openmotif-unaligned.diff, mwm.diff, openmotif-editres.diff,
    openmotif-editres-prototype.patch, motif-avoid-empty-include.diff,
    motif-sequence-points.diff, openmotif-2.3.1-suse-stipple.patch,
    and motif-2.3.4-implicit-fortify-decl.patch
- Added patches from upstream and alpine:
  * fix-format-security.patch
  * no-demos.patch
  * fix_underlinking.patch
  * fix_hardcoded_x11rgb_path.patch
  * fix-undefined-use-of-sprintf.patch
  * 18-option-main.patch
* Tue Feb 16 2016 schwab@suse.de
- motif-2.3.4-implicit-fortify-decl.patch: fix bad use of reserved
  identifier
* Sat Mar 28 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
- Remove old ppc obsoletes/provides
* Tue Oct 28 2014 i@marguerite.su
- Add motif-2.3.4-implicit-fortify-decl.patch
  * Fix implicit-fortify-decl and implicit-function-decl errors
* Tue May  6 2014 sndirsch@suse.com
- add pkgconfig(printproto) as requires to motif-devel
* Wed Mar  5 2014 jmatejek@suse.com
- openmotif-2.3.1-suse-stipple.patch - forward-port SLE's feature
  that allows disabling of upstream fix1381. This is necessary
  in some legacy scenarios, but undesirable in new apps. To enable
  the stipple feature (disable fix1381), set environment variable
  SUSE_OPENMOTIF_ENABLE_STIPPLE to 1.
* Mon Jul 15 2013 coolo@suse.com
- merge motif and openmotif
- add localonly service to recompress
* Tue Jul  9 2013 coolo@suse.com
- please legal-team (bnc#827674) by removing all files that
  have strange licenses
* Fri May  3 2013 matwey.kornilov@gmail.com
- Drop openmotif-libpng14.diff: fixed in upstream
* Sat Jan  5 2013 jengelh@inai.de
- Motif 2.3.4 strictly requires Xmu >= 1.1.1 (changed prototypes)
* Fri Jan  4 2013 jengelh@inai.de
- Follow shared library package guidelines
- Kill Requires: png/jpeg-devel, since there does not seem to be
  a requirement to have them to build motif programs
- Added motif-avoid-empty-include.diff, motif-sequence-points.diff
* Mon Oct 29 2012 msrb@novell.com
- Use MWMRCDIR instead of rcdir in spec file. (bnc#786848)
* Thu May 24 2012 vdziewiecki@suse.com
-Update to openmotif 2.3.3 (bnc#752334)
-Fixed a build failure caused by a function in builtin EditresCom.c not
  matching it's prototype.
* Wed Nov 16 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Apr  8 2010 pgajdos@suse.cz
- fixed build with libpng14
* Sat Dec 19 2009 bernhard@bwalle.de
- Update to openmotif 2.3.2
  o When we set XmNvisibleItemCount resource available in
    XmComboBox, the widget displays the wrong number of items
  o Added missing 'O' character to UTF8_SUPPORTED macro
  o PanedWindow orientation error
  o paned widget does not work under Fedora Core 2 with openmotif
    2.2.3-4.1
  o XmDropSiteRetrieve frees XRectangles before caller can use them
  o Build system changes.
- Refresh mwm.diff.
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Thu Apr 30 2009 mseben@suse.cz
- removed deprecated datadir.patch - we don't build demos ,
  added version dependency of openmotif-libs for openmotif-devel
* Wed Mar 18 2009 crrodriguez@suse.de
- fix build, deleting la files in wrong rpm spec section
* Tue Mar  3 2009 crrodriguez@suse.de
- remove static libraries
* Fri Jan  9 2009 schwab@suse.de
- Fix last change.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Nov 10 2008 schwab@suse.de
- Remove obsolete changes.
* Thu Oct  9 2008 bwalle@suse.de
- Update to openMotif 2.3.1.
  * Bug fixes, see ftp://ftp.ics.com/openmotif/2.3/2.3.1/RELEASE.
- Drop openmotif-etched-in-menus: Included in release.
- Drop openmotif-insensitive-label.diff: Included in release.
* Tue Apr 22 2008 bwalle@suse.de
- Fix look of etched-in menus (patch from
  http://bugs.motifzone.net/show_bug.cgi?id=1395)
* Sat Apr 12 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Nov 15 2007 bwalle@suse.de
- Fix configure warnings when checking for X11/Xmu/Editres.h.
- Fix problem that insensitive labels in buttons/menus are
  represented by a gray box (fix from upstream CVS).
* Tue Jul 24 2007 aj@suse.de
- Remove unneeded build require on xorg-x11.
* Mon Jul 23 2007 schwab@suse.de
- Fix location of system.mwmrc [#287207].
* Mon Jul 16 2007 schwab@suse.de
- Update to openMotif 2.3.0.
  * Client-side anti-aliased fonts support via XFT
  * UTF-8 and UTF8_STRING atom support
  * Ability to show text and pixmaps in Label, LabelGadget and all
    derived widgets
  * Support of PNG and JPEG image formats in the same way as XPM is supported
  * 26 bugs fixes
* Thu Apr  5 2007 schwab@suse.de
- Remove redundant compares.
* Tue Apr  3 2007 schwab@suse.de
- Add libpng-devel and libjpeg-devel to BuildRequires.
* Thu Mar 29 2007 rguenther@suse.de
- add flex BuildRequires.
* Sat Mar  3 2007 aj@suse.de
- /usr/share/xsessions is part of filesystems package now.
* Wed Jan 17 2007 schwab@suse.de
- Fix string compare.
* Fri Oct 13 2006 schwab@suse.de
- Fix XPM plausibility checks.
* Thu Aug 17 2006 schwab@suse.de
- Fix broken alignment.
* Wed Aug 16 2006 aj@suse.de
- Remove unneeded BuildRequire xorg-x11.
* Fri Aug  4 2006 schwab@suse.de
- Don't build demo programs.
* Mon Jul 24 2006 schwab@suse.de
- Fix building with Xorg 7.
* Wed Jun 14 2006 schwab@suse.de
- Set mandir.
* Wed Apr 12 2006 schwab@suse.de
- Fix build race.
* Mon Apr 10 2006 schwab@suse.de
- Update to openmotif 2.3.0 beta2.
* Fri Mar 31 2006 schwab@suse.de
- Fix fencepost error.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec  5 2005 schwab@suse.de
- Fix last change.
* Fri Dec  2 2005 schwab@suse.de
- Fix buffer overflows in uil [#136628].
* Tue Nov 29 2005 schwab@suse.de
- Fix missing sentinel.
* Tue Nov 29 2005 schwab@suse.de
- Remove useless buffer.
* Wed Nov 16 2005 uli@suse.de
- build with -O1 on ARM (prevents miscompilation that topples
  test suite)
* Wed Oct 19 2005 schwab@suse.de
- Update to openmotif 2.2.4.
* Sat Jul  9 2005 schwab@suse.de
- Fix warning.
* Tue May 17 2005 schwab@suse.de
- Completely rewrite XPM patch.
* Mon Feb 14 2005 schwab@suse.de
- Fix more sentinel warnings.
* Thu Feb 10 2005 adrian@suse.de
- install session desktop file
* Thu Jan 27 2005 schwab@suse.de
- Fix sentinel warnings.
* Wed Sep 29 2004 meissner@suse.de
- Fixed XPM security problem. #43240.
* Thu Sep  2 2004 schwab@suse.de
- Fix XmResizeHashTable [#44499].
* Tue Aug 17 2004 schwab@suse.de
- Fix dependencies.
* Tue Jun  1 2004 schwab@suse.de
- Fix use of datadir [#41476].
* Thu Apr 22 2004 schwab@suse.de
- Update to openMotif 2.2.3.
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Wed Feb 11 2004 schwab@suse.de
- Fix some font problem [#32143].
* Sat Aug 16 2003 adrian@suse.de
- let openmotif-devel require only openmotif-libs
* Wed Aug 13 2003 schwab@suse.de
- Run ldconfig in %%post of libs [#28737].
* Wed Apr 30 2003 adrian@suse.de
- split libs into sub package
* Tue Apr  8 2003 schwab@suse.de
- Fix 64 bit bug in input method handling [#24075].
* Wed Dec 11 2002 schwab@suse.de
- Fix makefiles for automake.
* Mon Nov 18 2002 schwab@suse.de
- Fix duplicate file in AC_OUTPUT.
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Sun May 26 2002 schwab@suse.de
- Fix invalid cast.
- Fix automake problem.
* Wed Apr 24 2002 schwab@suse.de
- Move /usr/X11R6/lib64/X11 back to /usr/X11R6/lib/X11.
* Wed Apr 24 2002 schwab@suse.de
- Fix for lib64.
* Thu Apr 18 2002 schwab@suse.de
- Fix permission of site.def after modifying.
* Thu Apr  4 2002 schwab@suse.de
- Remove dependency on libXmu to allow static linking.
* Wed Apr  3 2002 schwab@suse.de
- Update to openMotif 2.2.2.
- New subpackage openmotif-demo.
* Fri Jan  4 2002 adrian@suse.de
- fix build for mips
* Thu Nov 15 2001 schwab@suse.de
- Integrate JDK bug fix.
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Thu Feb 22 2001 schwab@suse.de
- Trigger on xdevel, not xf86.
* Fri Jan 19 2001 bk@suse.de
- Add support for s390.
* Fri Nov 17 2000 kukuk@suse.de
- Merge -binaries subpackage
* Wed Nov  8 2000 ro@suse.de
- changed %%post devel to %%triggerin devel -- xf86
* Tue Oct 24 2000 kukuk@suse.de
- Renamed from motif
- Split xmbind and mwm into extra "binary" package to avoid
  conflicts with lesstif
* Mon Sep 18 2000 schwab@suse.de
- Add support for ia64.
* Fri Jul 28 2000 kukuk@suse.de
- You cannot create an array with size NL_TEXTMAX == MAX_INT
- Add SPARC support to linux.cf
* Thu Jul 13 2000 schwab@suse.de
- Package created.
